@@ -24,6 +24,7 @@
 #define __GST_BASE_SINK_H__
 
 #include <gst/gst.h>
+#include <gst/base/base-prelude.h>
 
 G_BEGIN_DECLS
 
@@ -57,6 +58,20 @@ G_BEGIN_DECLS
 #define GST_BASE_SINK_PREROLL_SIGNAL(obj)     g_cond_signal (GST_BASE_SINK_GET_PREROLL_COND (obj));
 #define GST_BASE_SINK_PREROLL_BROADCAST(obj)  g_cond_broadcast (GST_BASE_SINK_GET_PREROLL_COND (obj));
 
+/**
+ * GST_BASE_SINK_FLOW_DROPPED:
+ *
+ * A #GstFlowReturn that can be returned from
+ * #GstBaseSinkClass::render to indicate that the output buffer was not
+ * rendered.
+ *
+ * Note that this is currently not support for #GstBaseSinkClass::render_list
+ * virtual method.
+ *
+ * Since: 1.24
+ */
+#define GST_BASE_SINK_FLOW_DROPPED     GST_FLOW_CUSTOM_SUCCESS
+
 typedef struct _GstBaseSink GstBaseSink;
 typedef struct _GstBaseSinkClass GstBaseSinkClass;
 typedef struct _GstBaseSinkPrivate GstBaseSinkPrivate;
@@ -124,10 +139,10 @@ struct _GstBaseSink {
  * @unlock: Unlock any pending access to the resource. Subclasses should
  *     unblock any blocked function ASAP and call gst_base_sink_wait_preroll()
  * @unlock_stop: Clear the previous unlock request. Subclasses should clear
- *     any state they set during #GstBaseSinkClass.unlock(), and be ready to
+ *     any state they set during #GstBaseSinkClass::unlock, and be ready to
  *     continue where they left off after gst_base_sink_wait_preroll(),
  *     gst_base_sink_wait() or gst_wait_sink_wait_clock() return or
- *     #GstBaseSinkClass.render() is called again.
+ *     #GstBaseSinkClass::render is called again.
  * @query: perform a #GstQuery on the element.
  * @event: Override this to handle events arriving on the sink pad
  * @wait_event: Override this to implement custom logic to wait for the event
@@ -150,7 +165,12 @@ struct _GstBaseSink {
 struct _GstBaseSinkClass {
   GstElementClass parent_class;
 
-  /* get caps from subclass */
+  /**
+   * GstBaseSinkClass::get_caps:
+   * @filter: (in) (nullable):
+   *
+   * Called to get sink pad caps from the subclass.
+   */
   GstCaps*      (*get_caps)     (GstBaseSink *sink, GstCaps *filter);
   /* notify subclass of new caps */
   gboolean      (*set_caps)     (GstBaseSink *sink, GstCaps *caps);
@@ -160,7 +180,13 @@ struct _GstBaseSinkClass {
   /* start or stop a pulling thread */
   gboolean      (*activate_pull)(GstBaseSink *sink, gboolean active);
 
-  /* get the start and end times for syncing on this buffer */
+  /**
+   * GstBaseSinkClass::get_times:
+   * @start: (out): the start #GstClockTime
+   * @end: (out): the end #GstClockTime
+   *
+   * Get the start and end times for syncing on this buffer.
+   */
   void          (*get_times)    (GstBaseSink *sink, GstBuffer *buffer,
                                  GstClockTime *start, GstClockTime *end);
 
@@ -201,124 +227,132 @@ struct _GstBaseSinkClass {
   gpointer       _gst_reserved[GST_PADDING_LARGE];
 };
 
-GST_EXPORT
+GST_BASE_API
 GType           gst_base_sink_get_type (void);
 
-GST_EXPORT
+GST_BASE_API
 GstFlowReturn   gst_base_sink_do_preroll        (GstBaseSink *sink, GstMiniObject *obj);
 
-GST_EXPORT
+GST_BASE_API
 GstFlowReturn   gst_base_sink_wait_preroll      (GstBaseSink *sink);
 
 /* synchronizing against the clock */
 
-GST_EXPORT
+GST_BASE_API
 void            gst_base_sink_set_sync          (GstBaseSink *sink, gboolean sync);
 
-GST_EXPORT
+GST_BASE_API
 gboolean        gst_base_sink_get_sync          (GstBaseSink *sink);
 
 /* Drop buffers which are out of segment */
 
-GST_EXPORT
+GST_BASE_API
 void            gst_base_sink_set_drop_out_of_segment (GstBaseSink *sink, gboolean drop_out_of_segment);
 
-GST_EXPORT
+GST_BASE_API
 gboolean        gst_base_sink_get_drop_out_of_segment (GstBaseSink *sink);
 
 /* dropping late buffers */
 
-GST_EXPORT
+GST_BASE_API
 void            gst_base_sink_set_max_lateness  (GstBaseSink *sink, gint64 max_lateness);
 
-GST_EXPORT
+GST_BASE_API
 gint64          gst_base_sink_get_max_lateness  (GstBaseSink *sink);
 
 /* performing QoS */
 
-GST_EXPORT
+GST_BASE_API
 void            gst_base_sink_set_qos_enabled   (GstBaseSink *sink, gboolean enabled);
 
-GST_EXPORT
+GST_BASE_API
 gboolean        gst_base_sink_is_qos_enabled    (GstBaseSink *sink);
 
 /* doing async state changes */
 
-GST_EXPORT
+GST_BASE_API
 void            gst_base_sink_set_async_enabled (GstBaseSink *sink, gboolean enabled);
 
-GST_EXPORT
+GST_BASE_API
 gboolean        gst_base_sink_is_async_enabled  (GstBaseSink *sink);
 
 /* tuning synchronisation */
 
-GST_EXPORT
+GST_BASE_API
 void            gst_base_sink_set_ts_offset     (GstBaseSink *sink, GstClockTimeDiff offset);
 
-GST_EXPORT
+GST_BASE_API
 GstClockTimeDiff gst_base_sink_get_ts_offset    (GstBaseSink *sink);
 
 /* last sample */
 
-GST_EXPORT
+GST_BASE_API
 GstSample *     gst_base_sink_get_last_sample   (GstBaseSink *sink);
 
-GST_EXPORT
+GST_BASE_API
 void            gst_base_sink_set_last_sample_enabled (GstBaseSink *sink, gboolean enabled);
 
-GST_EXPORT
+GST_BASE_API
 gboolean        gst_base_sink_is_last_sample_enabled (GstBaseSink *sink);
 
 /* latency */
 
-GST_EXPORT
+GST_BASE_API
 gboolean        gst_base_sink_query_latency     (GstBaseSink *sink, gboolean *live, gboolean *upstream_live,
                                                  GstClockTime *min_latency, GstClockTime *max_latency);
-GST_EXPORT
+GST_BASE_API
 GstClockTime    gst_base_sink_get_latency       (GstBaseSink *sink);
 
 /* render delay */
 
-GST_EXPORT
+GST_BASE_API
 void            gst_base_sink_set_render_delay  (GstBaseSink *sink, GstClockTime delay);
 
-GST_EXPORT
+GST_BASE_API
 GstClockTime    gst_base_sink_get_render_delay  (GstBaseSink *sink);
 
 /* blocksize */
 
-GST_EXPORT
+GST_BASE_API
 void            gst_base_sink_set_blocksize     (GstBaseSink *sink, guint blocksize);
 
-GST_EXPORT
+GST_BASE_API
 guint           gst_base_sink_get_blocksize     (GstBaseSink *sink);
 
 /* throttle-time */
 
-GST_EXPORT
+GST_BASE_API
 void            gst_base_sink_set_throttle_time (GstBaseSink *sink, guint64 throttle);
 
-GST_EXPORT
+GST_BASE_API
 guint64         gst_base_sink_get_throttle_time (GstBaseSink *sink);
 
 /* max-bitrate */
 
-GST_EXPORT
+GST_BASE_API
 void            gst_base_sink_set_max_bitrate   (GstBaseSink *sink, guint64 max_bitrate);
 
-GST_EXPORT
+GST_BASE_API
 guint64         gst_base_sink_get_max_bitrate   (GstBaseSink *sink);
 
-GST_EXPORT
+/* processing deadline */
+GST_BASE_API
+void            gst_base_sink_set_processing_deadline  (GstBaseSink *sink, GstClockTime processing_deadline);
+
+GST_BASE_API
+GstClockTime    gst_base_sink_get_processing_deadline  (GstBaseSink *sink);
+
+GST_BASE_API
 GstClockReturn  gst_base_sink_wait_clock        (GstBaseSink *sink, GstClockTime time,
                                                  GstClockTimeDiff * jitter);
-GST_EXPORT
+GST_BASE_API
 GstFlowReturn   gst_base_sink_wait              (GstBaseSink *sink, GstClockTime time,
                                                  GstClockTimeDiff *jitter);
 
-#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
+GST_BASE_API
+GstStructure 	*gst_base_sink_get_stats (GstBaseSink * sink);
+
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstBaseSink, gst_object_unref)
-#endif
 
 G_END_DECLS
 
