@@ -29,6 +29,7 @@
 #include <glib-object.h>
 
 #include <gst/gstcontrolsource.h>
+#include <gst/controller/controller-prelude.h>
 
 G_BEGIN_DECLS
 
@@ -85,19 +86,17 @@ struct _GstARGBControlBindingClass
   gpointer _gst_reserved[GST_PADDING];
 };
 
-GST_EXPORT
+GST_CONTROLLER_API
 GType gst_argb_control_binding_get_type (void);
 
 /* Functions */
 
-GST_EXPORT
+GST_CONTROLLER_API
 GstControlBinding * gst_argb_control_binding_new   (GstObject * object, const gchar * property_name,
                                                             GstControlSource * cs_a, GstControlSource * cs_r,
                                                             GstControlSource * cs_g, GstControlSource * cs_b);
 
-#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstARGBControlBinding, gst_object_unref)
-#endif
 
 G_END_DECLS
 
