@@ -64,7 +64,7 @@ GST_START_TEST (test_submemory)
   gst_memory_unmap (sub, &sinfo);
   gst_memory_unref (sub);
 
-  /* test if metadata is coppied, not a complete memory copy so only the
+  /* test if metadata is copied, not a complete memory copy so only the
    * timestamp and offset fields are copied. */
   sub = gst_memory_share (memory, 0, 1);
   fail_if (sub == NULL, "share of memory returned NULL");
@@ -72,7 +72,7 @@ GST_START_TEST (test_submemory)
       "submemory has wrong size");
   gst_memory_unref (sub);
 
-  /* test if metadata is coppied, a complete memory is copied so all the timing
+  /* test if metadata is copied, a complete memory is copied so all the timing
    * fields should be copied. */
   sub = gst_memory_share (memory, 0, 4);
   fail_if (sub == NULL, "share of memory returned NULL");
@@ -209,7 +209,7 @@ GST_START_TEST (test_copy)
   copy = gst_memory_copy (memory, 0, -1);
   ASSERT_MINI_OBJECT_REFCOUNT (memory, "memory", 1);
   ASSERT_MINI_OBJECT_REFCOUNT (copy, "copy", 1);
-  /* memorys are copied and must point to different memory */
+  /* memory is copied and must point to different memory */
   fail_if (memory == copy);
 
   fail_unless (gst_memory_map (memory, &info, GST_MAP_READ));
@@ -588,7 +588,7 @@ static GstMemory *
 _my_opaque_alloc (GstAllocator * allocator, gsize size,
     GstAllocationParams * params)
 {
-  MyOpaqueMemory *mem = g_slice_new (MyOpaqueMemory);
+  MyOpaqueMemory *mem = g_new (MyOpaqueMemory, 1);
   gsize maxsize = size + params->prefix + params->padding;
 
   gst_memory_init (GST_MEMORY_CAST (mem), params->flags, allocator, NULL,
@@ -605,13 +605,13 @@ _my_opaque_free (GstAllocator * allocator, GstMemory * mem)
   MyOpaqueMemory *mmem = (MyOpaqueMemory *) mem;
 
   g_free (mmem->data);
-  g_slice_free (MyOpaqueMemory, mmem);
+  g_free (mmem);
 }
 
 static gpointer
 _my_opaque_mem_map (MyOpaqueMemory * mem, gsize maxsize, GstMapFlags flags)
 {
-  /* the subclass is reponsible for logging any error, by design choice and for
+  /* the subclass is responsible for logging any error, by design choice and for
    * testing purpose MyOpaqueMemory never logs any trace */
   return NULL;
 }
@@ -679,10 +679,10 @@ _custom_log_func (GstDebugCategory * category,
     GstDebugLevel level, const gchar * file, const gchar * function,
     gint line, GObject * object, GstDebugMessage * message, gpointer unused)
 {
-  const gchar *dbg_msg = gst_debug_message_get (message);
-  fail_unless (dbg_msg == NULL);
+  ck_assert_uint_gt (level, GST_LEVEL_WARNING);
 }
 
+#ifndef GST_DISABLE_GST_DEBUG
 GST_START_TEST (test_no_error_and_no_warning_on_map_failure)
 {
   GstAllocator *alloc;
@@ -713,7 +713,7 @@ GST_START_TEST (test_no_error_and_no_warning_on_map_failure)
   gst_debug_add_log_function (_custom_log_func, NULL, NULL);
 
   /* Ensure that the map does not log any error on failure. It has to fail
-   * because the custom opaque memory here is desgined to not be mappable. */
+   * because the custom opaque memory here is designed to not be mappable. */
   fail_if (gst_memory_map (mem, &info, GST_MAP_READ));
   fail_if (info.data != NULL);
   fail_if (info.size != 0);
@@ -735,6 +735,7 @@ GST_START_TEST (test_no_error_and_no_warning_on_map_failure)
 }
 
 GST_END_TEST;
+#endif /* !GST_DISABLE_GST_DEBUG */
 
 static Suite *
 gst_memory_suite (void)
@@ -755,7 +756,9 @@ gst_memory_suite (void)
   tcase_add_test (tc_chain, test_map_resize);
   tcase_add_test (tc_chain, test_alloc_params);
   tcase_add_test (tc_chain, test_lock);
+#ifndef GST_DISABLE_GST_DEBUG
   tcase_add_test (tc_chain, test_no_error_and_no_warning_on_map_failure);
+#endif
 
   return s;
 }
