@@ -48,7 +48,7 @@ struct _GstFakeObjectClass
 static GType
 gst_fake_object_get_type (void)
 {
-  static volatile gsize fake_object_type = 0;
+  static gsize fake_object_type = 0;
 
   if (g_once_init_enter (&fake_object_type)) {
     GType type;
@@ -284,12 +284,18 @@ GST_START_TEST (test_fake_object_name_threaded_right)
 
   /* start looping and set/get name repeatedly */
   for (i = 0; i < 1000; ++i) {
+#ifndef g_autoptr
     GST_OBJECT_LOCK (object);
+#else
+    GST_OBJECT_AUTO_LOCK (object, locker);
+#endif
     g_free (GST_OBJECT_NAME (object));
     GST_OBJECT_NAME (object) = g_strdup ("main");
     THREAD_SWITCH ();
     name = g_strdup (GST_OBJECT_NAME (object));
+#ifndef g_autoptr
     GST_OBJECT_UNLOCK (object);
+#endif
 
     fail_unless (strcmp (name, "main") == 0,
         "Name got changed while lock held during run %d", i);
@@ -403,7 +409,7 @@ GST_START_TEST (test_fake_object_name_threaded_unique)
   g_free (name1);
 
   /* free stuff */
-  g_list_foreach (object_list, (GFunc) g_object_unref, NULL);
+  g_list_foreach (object_list, (GFunc) gst_object_unref, NULL);
 }
 
 GST_END_TEST;
