@@ -269,8 +269,8 @@ run_parser_playback_test (GList * input, gint expected_output, gdouble rate)
   GstSegment segment;
 
   gst_pad_set_active (mysrcpad, TRUE);
-  gst_element_set_state (parsetest, GST_STATE_PLAYING);
   gst_pad_set_active (mysinkpad, TRUE);
+  gst_element_set_state (parsetest, GST_STATE_PLAYING);
 
   send_startup_events ();
 
@@ -477,8 +477,8 @@ GST_START_TEST (parser_reverse_playback)
   gst_pad_set_event_function (mysinkpad, _sink_event);
 
   gst_pad_set_active (mysrcpad, TRUE);
-  gst_element_set_state (parsetest, GST_STATE_PLAYING);
   gst_pad_set_active (mysinkpad, TRUE);
+  gst_element_set_state (parsetest, GST_STATE_PLAYING);
 
   g_main_loop_run (loop);
   fail_unless (have_eos == TRUE);
@@ -582,8 +582,8 @@ GST_START_TEST (parser_pull_short_read)
   gst_base_parse_set_min_frame_size (GST_BASE_PARSE (parsetest), 1024);
 
   gst_pad_set_active (mysrcpad, TRUE);
-  gst_element_set_state (parsetest, GST_STATE_PLAYING);
   gst_pad_set_active (mysinkpad, TRUE);
+  gst_element_set_state (parsetest, GST_STATE_PLAYING);
 
   g_main_loop_run (loop);
   fail_unless_equals_int (have_eos, TRUE);
@@ -662,8 +662,8 @@ GST_START_TEST (parser_pull_frame_growth)
   gst_base_parse_set_min_frame_size (GST_BASE_PARSE (parsetest), 1024);
 
   gst_pad_set_active (mysrcpad, TRUE);
-  gst_element_set_state (parsetest, GST_STATE_PLAYING);
   gst_pad_set_active (mysinkpad, TRUE);
+  gst_element_set_state (parsetest, GST_STATE_PLAYING);
 
   g_main_loop_run (loop);
   fail_unless (have_eos == TRUE);
@@ -722,6 +722,87 @@ GST_START_TEST (parser_initial_gap_prefer_upstream_caps)
 
 GST_END_TEST;
 
+GST_START_TEST (parser_convert_duration)
+{
+  static const gint64 seconds = 45 * 60;
+  gint64 value, expect;
+  gboolean ret;
+
+  have_eos = FALSE;
+  have_data = FALSE;
+  loop = g_main_loop_new (NULL, FALSE);
+
+  setup_parsertester ();
+  gst_pad_set_getrange_function (mysrcpad, _src_getrange);
+  gst_pad_set_query_function (mysrcpad, _src_query);
+  gst_pad_set_chain_function (mysinkpad, _sink_chain);
+  gst_pad_set_event_function (mysinkpad, _sink_event);
+
+  gst_pad_set_active (mysrcpad, TRUE);
+  gst_pad_set_active (mysinkpad, TRUE);
+  gst_element_set_state (parsetest, GST_STATE_PLAYING);
+
+  g_main_loop_run (loop);
+  fail_unless (have_eos == TRUE);
+  fail_unless (have_data == TRUE);
+
+  ret = gst_base_parse_convert_default (GST_BASE_PARSE (parsetest),
+      GST_FORMAT_TIME, seconds * GST_SECOND, GST_FORMAT_BYTES, &value);
+  fail_unless (ret == TRUE);
+  expect = gst_util_uint64_scale_round (seconds * sizeof (guint64),
+      TEST_VIDEO_FPS_N, TEST_VIDEO_FPS_D);
+  fail_unless_equals_int (value, expect);
+  gst_element_set_state (parsetest, GST_STATE_NULL);
+
+  check_no_error_received ();
+  cleanup_parsertest ();
+
+  g_main_loop_unref (loop);
+  loop = NULL;
+}
+
+GST_END_TEST;
+
+GST_START_TEST (parser_sticky_events_after_flush)
+{
+  GstHarness *h;
+  GstEvent *e;
+  GstSegment segment;
+  GstStreamCollection *collection;
+
+  parsetest = g_object_new (GST_PARSER_TESTER_TYPE, NULL);
+
+  h = gst_harness_new_with_element (parsetest, "sink", "src");
+  gst_harness_set_caps (h, gst_caps_new_empty_simple ("video/x-test-custom"),
+      gst_caps_new_empty_simple ("video/x-test-custom"));
+
+  collection = gst_stream_collection_new ("test");
+  fail_unless (gst_harness_push_event (h,
+          gst_event_new_stream_collection (collection)));
+  gst_object_unref (collection);
+
+  fail_unless (gst_harness_push_event (h, gst_event_new_flush_start ()));
+  fail_unless (gst_harness_push_event (h, gst_event_new_flush_stop (FALSE)));
+
+  gst_segment_init (&segment, GST_FORMAT_TIME);
+  fail_unless (gst_harness_push_event (h, gst_event_new_segment (&segment)));
+  fail_unless (gst_harness_push (h, create_test_buffer (1)) == GST_FLOW_OK);
+
+  // FLUSH_STOP should not clear STREAM_COLLECTION
+  while (TRUE) {
+    fail_unless (e = gst_harness_pull_event (h));
+    if (GST_EVENT_TYPE (e) == GST_EVENT_STREAM_COLLECTION)
+      break;
+    gst_event_unref (e);
+  }
+  gst_event_unref (e);
+
+  gst_harness_teardown (h);
+  gst_object_unref (parsetest);
+}
+
+GST_END_TEST;
+
 
 static void
 baseparse_setup (void)
@@ -755,6 +836,8 @@ gst_baseparse_suite (void)
   tcase_add_test (tc, parser_pull_short_read);
   tcase_add_test (tc, parser_pull_frame_growth);
   tcase_add_test (tc, parser_initial_gap_prefer_upstream_caps);
+  tcase_add_test (tc, parser_convert_duration);
+  tcase_add_test (tc, parser_sticky_events_after_flush);
 
   return s;
 }
